@@ -15,10 +15,8 @@ from gracy.throttling import ThrottleController
 
 class LogLevel(IntEnum):
     CRITICAL = logging.CRITICAL
-    FATAL = logging.FATAL
     ERROR = logging.ERROR
     WARNING = logging.WARNING
-    WARN = logging.WARN
     INFO = logging.INFO
     DEBUG = logging.DEBUG
     NOTSET = logging.NOTSET
